--[[ LUA variables in WTF ]]
local _
local ADDON, P = ...
local CSP = LibStub("AceAddon-3.0"):GetAddon(ADDON)
function CSP:ProfileChanged() -- LUA stored variables changed
  self.DB = self.AceDB.profile
end
local defaults = {
  profile = {
    popups = {
      ["CONFIRM_FOLLOWER_UPGRADE"] = true,
      ["CONFIRM_PURCHASE_TOKEN_ITEM"] = true,
      ["CONFIRM_REFUND_TOKEN_ITEM"] = true,
      ["CONFIRM_UPGRADE_ITEM"] = true,
      ["CONFIRM_LEAVE_INSTANCE_PARTY"] = true,
      ["CONFIRM_RESET_INSTANCES"] = true,
      ["VOID_STORAGE_DEPOSIT_CONFIRMATION"] = false,
      ["CONFIRM_PURCHASE_NONREFUNDABLE_ITEM"] = false,
      ["CONFIRM_MAIL_ITEM_UNREFUNDABLE"] = false,
      ["CONFIRM_HIGH_COST_ITEM"] = false, 
      ["DELETE_ITEM"] = false,
      ["DELETE_GOOD_ITEM"] = false,
    },
    verbose = true,
  },
}
function CSP:ProfileLoad() -- LUA stored variables load and init
  self.AceDB = LibStub("AceDB-3.0"):New("ConfirmSP",defaults,'Default')
  self.AceDB.RegisterCallback(self, "OnProfileChanged", "ProfileChanged")
  self.AceDB.RegisterCallback(self, "OnProfileCopied",  "ProfileChanged")
  self.AceDB.RegisterCallback(self, "OnProfileReset",   "ProfileChanged")
  self.DB  = self.AceDB.profile
end
local function PopupOptions()
  local args, index = {}, 1
  for key, val in pairs(defaults.profile.popups) do
    args[key] = {
      name = key,
      desc = _G[key],
      order = index,
      type = "toggle",
      width = "full", 
      set = function(info,val) CSP.DB.popups[info[#info]] = val; end,
      get = function(info) if CSP.DB.popups[info[#info]] ~= nil then return CSP.DB.popups[info[#info]] end; return false; end, 
    }
    index = index + 1
  end
  return args
end
function CSP:OptionsLoad() -- load options for UI config
  local ConfirmSPOptions = {
    type = "group",
    args = {
      ver = {
        name = P.VERSION,
        type = "header",
        order = 0,
        width = "full",    
      },
      verbose = {
        name = P.L["VERBOSE"],
        order = 1,
        type = "toggle",
        width = "full", 
        set = function(info,val) CSP.DB.verbose = val; end,
        get = function(info) if CSP.DB.verbose ~= nil then return CSP.DB.verbose end; return true; end, 
      },
      toggle = {
        order = 2,
        name = P.L["AUTOANSWER"],
        type = "group",
        args = PopupOptions(),
      },
    },
  }
  ConfirmSPOptions.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.AceDB)
  LibStub("AceConfig-3.0"):RegisterOptionsTable(P.TITLE, ConfirmSPOptions)
  LibStub("AceConfigDialog-3.0"):AddToBlizOptions(P.TITLE,ADDON,nil)
end
